.. _corporate_incidence:

Distributing the Corporate Income Tax
======================================

**corporate_incidence**

taxbrain.corporate_incidence
------------------------------------------

.. currentmodule:: taxbrain.corporate_incidence

.. automodule:: taxbrain.corporate_incidence
  :members: distribute, _update_income
